Ls.hun = {
	"tt": 'Magyar',

	"cols": {
		"c": 'műveletek',
		"dur": 'hossz',
		"q": 'minőség / bitrate',
		"Ac": 'audió kodek',
		"Vc": 'videó kodek',
		"Fmt": 'konténer',
		"Ahash": 'audió hash',
		"Vhash": 'videó hash',
		"Res": 'felbontás',
		"T": 'típus',
		"aq": 'audió minőség / bitrate',
		"vq": 'videó minőség / bitrate',
		"pixfmt": 'színkódolás / pixel',
		"resw": 'szélesség',
		"resh": 'magasság',
		"chs": 'csatornák',
		"hz": 'mintavételezés',
	},

	"hks": [
		[
			'egyéb',
			['ESC', 'minden bezárása'],

			'fájlkezelő',
			['G', 'lista / rács nézet'],
			['T', 'ikon / indexkép váltás'],
			['⇧ A/D', 'méret módosítása'],
			['ctrl-K', 'kijelöltek törlése'],
			['ctrl-X', 'kivágás vágólapra'],
			['ctrl-C', 'másolás vágólapra'],
			['ctrl-V', 'beillesztés ide'],
			['Y', 'kijelöltek letöltése'],
			['F2', 'átnevezés'],

			'kijelölés',
			['space', 'fájl kijelölése'],
			['↑/↓', 'kurzor mozgatása'],
			['ctrl ↑/↓', 'kurzor + nézet mozgatása'],
			['⇧ ↑/↓', 'fájlok kijelölése'],
			['ctrl-A', 'mindet kijelöli'],
		],
		[
			'navigáció',
			['B', 'fa / breadcrumbs váltás'],
			['I/K', 'előző/következő mappa'],
			['M', 'vissza a főmappába'],
			['V', 'fájlok mutatása az oldalsávon'],
			['A/D', 'oldalsáv mérete'],
		],
		[
			'zenelejátszó',
			['J/L', 'előző/következő szám'],
			['U/O', '10 mp tekerés (vissza/előre)'],
			['0..9', 'ugrás (0%..90%)'],
			['P', 'play/pause'],
			['S', 'épp szóló szám kijelölése'],
			['Y', 'szám letöltése'],
		],
		[
			'képnézegető',
			['J/L, ←/→', 'előző/következő kép'],
			['Home/End', 'első/utolsó kép'],
			['F', 'teljes képernyő'],
			['R', 'forgatás jobbra'],
			['⇧ R', 'forgatás balra'],
			['S', 'kép kijelölése'],
			['Y', 'kép letöltése'],
		],
		[
			'videólejátszó',
			['U/O', '10 mp tekerés (vissza/előre)'],
			['P/K/Space', 'play/pause'],
			['C', 'folyamatos lejátszás'],
			['V', 'ismétlés'],
			['M', 'némítás'],
			['[ és ]', 'ismétlési tartomány'],
		],
		[
			'szövegszerkesztő',
			['I/K', 'előző/következő fájl'],
			['M', 'bezárás'],
			['E', 'szerkesztés'],
			['S', 'kijelöl fv művelethez'],
			['Y', 'letöltés'],
			['⇧ J', 'json formázás (beautify)'],
		],
	],

	"m_ok": 'ok',
	"m_ng": 'mégse',

	"enable": 'bekapcsolva',
	"danger": 'FIGYELEM',
	"clipped": 'vágólapra másolva',

	"ht_s1": 'másodperce',
	"ht_s2": 'másodperce',
	"ht_m1": 'perce',
	"ht_m2": 'perce',
	"ht_h1": 'órája',
	"ht_h2": 'órája',
	"ht_d1": 'napja',
	"ht_d2": 'napja',
	"ht_and": ' és ',

	"goh": 'irányítópult',
	"gop": 'előző mappába">előző',
	"gou": 'szülőmappa">fel',
	"gon": 'következő mappába">következő',
	"logout": 'Kilépés ',
	"login": 'Belépés',
	"access": ' hozzáférés',
	"ot_close": 'almenü bezárása',
	"ot_search": '`keresés attribútumok, név, elérési út vagy metaadatok alapján$N$N`valami más` = szerepelnie kell mindkettőnek,$N`valami -más` = tartalmazza a «valami»-t, de a «más»-t nem,$N`^kezd .mp3$` = «kezd»-del induló mp3 fájlok$N`&quot;pontosan ez&quot;` = pontos egyezés$N$Ndátum formátum iso-8601, pl.$N`2024-12-31` vagy `2024-09-12 23:30:00`',
	"ot_unpost": 'töröld a nemrég feltöltött fájljaidat, vagy állítsd le a folyamatban lévőket',
	"ot_bup": 'bup: egyszerű feltöltő (még netscape 4-en is megy)',
	"ot_mkdir": 'új mappa létrehozása',
	"ot_md": 'új szöveges fájl',
	"ot_msg": 'üzenet küldése a szerver logba',
	"ot_mp": 'lejátszó beállításai',
	"ot_cfg": 'beállítások',
	"ot_u2i": 'up2k: fájlok feltöltése (ha van írási jogod) vagy keresés a szerveren$N$Nfolytatható, többszálú, dátumokat megőrzi, de CPU-éhesebb az egyszerű [🎈]-nél.<br /><br />feltöltés közben az ikon mutatja a haladást!',
	"ot_u2w": 'up2k: feltöltés folytatási támogatással (böngésző bezárás után is folytathatod)$N$Ntöbbszálú, dátumokat megőrzi, de CPU-éhesebb az egyszerűnél.<br /><br />feltöltés közben az ikon mutatja a haladást!',
	"ot_noie": 'Kérlek használj Chrome-ot / Firefox-ot / Edge-et',

	"ab_mkdir": 'mappa létrehozása',
	"ab_mkdoc": 'új szövegfájl',
	"ab_msg": 'log üzenet küldése',

	"ay_path": 'ugrás a mappákhoz',
	"ay_files": 'ugrás a fájlokhoz',

	"wt_ren": 'átnevezés$Ngyorsbillentyű: F2',
	"wt_del": 'törlés$Ngyorsbillentyű: ctrl-K',
	"wt_cut": 'kivágás &lt;small&gt;(beillesztéshez)&lt;/small&gt;$Ngyorsbillentyű: ctrl-X',
	"wt_cpy": 'másolás vágólapra$Ngyorsbillentyű: ctrl-C',
	"wt_pst": 'beillesztés$Ngyorsbillentyű: ctrl-V',
	"wt_selall": 'összes kijelölése$Ngyorsbillentyű: ctrl-A',
	"wt_selinv": 'kijelölés megfordítása',
	"wt_zip1": 'mappa letöltése zip/tar-ként',
	"wt_selzip": 'kijelöltek letöltése archívumként',
	"wt_seldl": 'kijelöltek letöltése külön fájlokként$Ngyorsbillentyű: Y',
	"wt_npirc": 'irc-formátumú infó másolása',
	"wt_nptxt": 'egyszerű szöveges infó másolása',
	"wt_m3ua": 'hozzáadás m3u listához (később <code>📻másolás</code>)',
	"wt_m3uc": 'm3u lista másolása vágólapra',
	"wt_grid": 'lista / rács nézet váltás$Ngyorsbillentyű: G',
	"wt_prev": 'előző szám$Ngyorsbillentyű: J',
	"wt_play": 'lejátszás / szünet$Ngyorsbillentyű: P',
	"wt_next": 'következő szám$Ngyorsbillentyű: L',

	"ul_par": 'párhuzamos szálak:',
	"ut_rand": 'véletlen fájlnevek',
	"ut_u2ts": 'helyi dátumok$Nátvitele a szerverre">📅',
	"ut_ow": 'felülírás?$N🛡️: soha (új nevet ad)$N🕒: csak ha a tiéd újabb$N♻️: mindig, ha más a tartalom$N⏭️: létezőket kihagy',
	"ut_mt": 'háttérben hashelés feltöltés alatt$N$Nkapcsold ki, ha fagy a géped',
	"ut_ask": 'megerősítés feltöltés előtt">💭',
	"ut_pot": 'feltöltés gyorsítása (egyszerűbb UI)',
	"ut_srch": 'csak létezés ellenőrzése$N(nem tölt fel semmit)',
	"ut_par": '0 = szünet$N$Nnöveld, ha lassú a net$N$NHDD limit vagy LAN esetén hagyd 1-en',
	"ul_btn": 'dobd ide a fájlokat/mappákat<br>(vagy kattints)',
	"ul_btnu": 'F E L T Ö L T É S',
	"ul_btns": 'K E R E S É S',

	"ul_hash": 'hash',
	"ul_send": 'küldés',
	"ul_done": 'kész',
	"ul_idle1": 'nincs várakozó feltöltés',
	"ut_etah": 'átlagos &lt;em&gt;hashelési&lt;/em&gt; sebesség és becsült idő',
	"ut_etau": 'átlagos &lt;em&gt;feltöltési&lt;/em&gt; sebesség és becsült idő',
	"ut_etat": 'átlagos &lt;em&gt;össz&lt;/em&gt; sebesség és becsült idő',

	"uct_ok": 'sikerült',
	"uct_ng": 'hiba / elutasítva',
	"uct_done": 'összesen',
	"uct_bz": 'hashelés vagy feltöltés...',
	"uct_q": 'várakozik',

	"utl_name": 'fájlnév',
	"utl_ulist": 'lista',
	"utl_ucopy": 'másolás',
	"utl_links": 'linkek',
	"utl_stat": 'státusz',
	"utl_prog": 'haladás',

	"utl_404": '404',
	"utl_err": 'HIBA',
	"utl_oserr": 'OS-hiba',
	"utl_found": 'megvan',
	"utl_defer": 'halasztva',
	"utl_yolo": 'YOLO',
	"utl_done": 'kész',

	"ul_flagblk": 'fájlok a várólistán</b><br>egy másik lapon már fut egy feltöltés,<br>megvárjuk, amíg az végez',
	"ul_btnlk": 'szerveroldali korlátozás miatt nem módosítható',

	"udt_up": 'Feltöltés',
	"udt_srch": 'Keresés',
	"udt_drop": 'dobd ide',

	"u_nav_m": '<h6>mit töltsünk fel?</h6><code>Enter</code> = Fájlok (egy vagy több)\n<code>ESC</code> = Egy mappa (almappákkal)',
	"u_nav_b": '<a href="#" id="modal-ok">Fájlok</a><a href="#" id="modal-ng">Egy mappa</a>',

	"cl_opts": 'beállítások',
	"cl_hfsz": 'méret',
	"cl_themes": 'téma',
	"cl_langs": 'nyelv',
	"cl_ziptype": 'mappa letöltés',
	"cl_uopts": 'up2k beállítások',
	"cl_favico": 'favicon',
	"cl_bigdir": 'limit feletti mappák',
	"cl_hsort": '#rendezés',
	"cl_keytype": 'hangnem-jelölés',
	"cl_hiddenc": 'rejtett oszlopok',
	"cl_hidec": 'rejt',
	"cl_reset": 'alaphelyzet',
	"cl_hpick": 'kattints az oszlopfejlécre az elrejtéshez',
	"cl_hcancel": 'elrejtés megszakítva',
	"cl_rcm": 'jobb-klikkes menü',

	"ct_grid": '田 rács nézet',
	"ct_ttips": '◔ ◡ ◔">ℹ️ segítő szövegek',
	"ct_thumb": 'rács nézetben ikonok/indexképek váltása$Ngyorsbillentyű: T">🖼️ képek',
	"ct_csel": 'kijelölés CTRL és SHIFT gombokkal rács nézetben">kijelölés',
	"ct_dsel": 'kijelölés egérhúzással rács nézetben">húzás',
	"ct_dl": 'azonnali letöltés (beágyazás helyett)">letöltés',
	"ct_ihop": 'nézegető bezárásakor ugorjon az utolsó képhez">g⮯',
	"ct_dots": 'rejtett fájlok mutatása (ha szabad)">rejtett',
	"ct_qdel": 'csak egyszer kérdezzen rá a törlésre">gyorstörlés',
	"ct_dir1st": 'mappák előre rendezése">📁 előre',
	"ct_nsort": 'természetes rendezés (pl. 1, 2, 10)">rendezés',
	"ct_utc": 'időpontok UTC-ben">UTC',
	"ct_readme": 'README.md mutatása a mappákban">📜 readme',
	"ct_idxh": 'index.html mutatása listázás helyett">htm',
	"ct_sbars": 'gördítősávok mutatása">⟊',

	"cut_umod": 'létező fájl dátumának frissítése a helyire (írható+törölhető jog kell)">re📅',

	"cut_turbo": 'yolo gomb, nem ajánlott:$N$Nrengeteg fájl újraellenőrzéséhez jó$N$Ncsak méretet néz, tartalmat nem! ha a méret egyezik, NEM tölti újra, még ha a fájl más is.$N$Nha kész vagy, kapcsold ki!">turbo',

	"cut_datechk": 'csak turbo módban számít$N$Nnézi a dátumokat is a méret mellé$N$Nvalamivel biztosabb a turbónál, de nem váltja ki a rendes ellenőrzést">dátum-chk',

	"cut_u2sz": 'feltöltési egység (chunk) mérete (MiB); nagy érték jó a távoli szerverekhez, kicsi a gyenge nethez',

	"cut_flag": 'egyszerre csak egy fül tölthessen fel (azonos domainen belül hat)',

	"cut_az": 'fájlok feltöltése ABC-sorrendben (nem a legkisebb-először módon)',

	"cut_nag": 'értesítés, ha kész a feltöltés (ha nem ezen a fülön állsz)',
	"cut_sfx": 'hangjelzés, ha kész a feltöltés',

	"cut_mt": 'többszálú hashelés (gyorsítás)$N$Nplusz RAM-ot kér (max 512 MiB)$N$Nhttps-t 30%-kal, http-t 4.5x gyorsítja">mt',

	"cut_wasm": 'wasm hashelő; chrome-on gyorsabb, de CPU-igényes és régebbi verzióknál fagyhat">wasm',

	"cft_text": 'favicon szöveg (üresen kikapcsol)',
	"cft_fg": 'szöveg színe',
	"cft_bg": 'háttér színe',

	"cdt_lim": 'lista hossza (max fájl/mappa)',
	"cdt_ask": 'lista végén ne töltsön be automatikusan, inkább kérdezzen rá',
	"cdt_hsort": 'rendezési szabályok száma a linkekben. 0 = tiltás',
	"cdt_ren": 'egyedi jobb-klikkes menü (gyári: SHIFT + jobb-klikk)">bekapcsolva',
	"cdt_rdb": 'mutassa a böngészőnek jobb-klikkes menüjét, ha az egyedi már nyitva van és megint jobb-klikkelsz">dupla',

	"tt_entree": 'oldalsáv (mappafa) mutatása$Ngyorsbillentyű: B',
	"tt_detree": 'elérési út mutatása$Ngyorsbillentyű: B',
	"tt_visdir": 'gördítés a kijelölt mappához',
	"tt_ftree": 'mappák / szövegfájlok váltása$Ngyorsbillentyű: V',
	"tt_pdock": 'szülőmappák rögzítése felül',
	"tt_dynt": 'automatikus méretezés nyitáskor',
	"tt_wrap": 'sortörés',
	"tt_hover": 'túl hosszú sorok mutatása rámutatáskor',

	"ml_pmode": 'mappa végén...',
	"ml_btns": 'gombok',
	"ml_tcode": 'átkódolás',
	"ml_tcode2": 'átkódolás ide:',
	"ml_tint": 'színezés',
	"ml_eq": 'eq',
	"ml_drc": 'dinamikatartomány-tömörítő',
	"ml_ss": 'csönd átugrása',

	"mt_loop": 'egy szám ismétlése">🔁',
	"mt_one": 'leállás egy szám után">1️⃣',
	"mt_shuf": 'véletlenszerű lejátszás mappánként">🔀',
	"mt_aplay": 'automatikus kezdés a link alapján$N$Nha kikapcsolod, a linkek sem fognak szám-azonosítót tartalmazni">a▶',
	"mt_preload": 'következő szám betöltése a végén (gapless)">preload',
	"mt_prescan": 'mappaváltás az utolsó szám vége előtt, hogy a böngésző ne álljon le">nav',
	"mt_fullpre": 'teljes szám előtöltése;$N✅ instabil netre,$N❌ lassú neten inkább kapcsold ki">full',
	"mt_fau": 'mobilon megakadályozza a leállást, ha lassú az előtöltés (a tagek kijelzése hibás lehet)">☕️',
	"mt_waves": 'hullámforma a tekerősávon:$Nhangerő amplitúdó mutatása a sávban">~s',
	"mt_npclip": 'gombok a most szóló szám infójának másolásához">/np',
	"mt_m3u_c": 'gombok a kijelöltek m3u8 listába másolásához">📻',
	"mt_octl": 'rendszerintegráció (média gombok / osd)">os-ctl',
	"mt_oseek": 'tekerés engedése a rendszer szinten$N$Nmegjegyzés: iphonon ez felülírja a következő szám gombot">seek',
	"mt_oscv": 'albumkép mutatása az osd-n">art',
	"mt_follow": 'fókuszban tartja az aktuális számot">🎯',
	"mt_compact": 'kompakt vezérlők">⟎',
	"mt_uncache": 'gyorsítótár ürítése (próbáld ezt, ha a böngésző hibás fájlt mentett el és nem játssza le)">uncache',
	"mt_mloop": 'mappa ismétlése">🔁 ismétlés',
	"mt_mnext": 'következő mappa betöltése és folytatás">📂 tovább',
	"mt_mstop": 'stop">⏸ stop',
	"mt_cflac": 'flac / wav konvertálása ide: {0}">flac',
	"mt_caac": 'aac / m4a konvertálása ide: {0}">aac',
	"mt_coth": 'egyéb (nem mp3) konvertálása ide: {0}">egyéb',
	"mt_c2opus": 'asztali gép, laptop, android kedvence">opus',
	"mt_c2owa": 'opus-weba (iOS 17.5+)">owa',
	"mt_c2caf": 'opus-caf (iOS 11-17)">caf',
	"mt_c2mp3": 'nagyon régi eszközökhöz">mp3',
	"mt_c2flac": 'legjobb minőség, de hatalmas fájlok">flac',
	"mt_c2wav": 'tömörítetlen (még nagyobb)">wav',
	"mt_c2ok": 'szuper, jó választás',
	"mt_c2nd": 'nem javasolt ehhez az eszközhöz, de rendben',
	"mt_c2ng": 'úgy tűnik, az eszközöd nem támogatja, de próbáljuk meg',
	"mt_xowa": 'iOS hiba akadályozza a háttérben lejátszást ezzel; használd inkább a caf-ot vagy mp3-at',
	"mt_tint": 'háttérszint (0-100) a tekerősávon, hogy ne zavarjon a betöltés',
	"mt_eq": '`eq és erősítés;$N$Nboost `0` = alap hangerő (100%)$N$Nszélesség `1 &nbsp;` = standard sztereó$Nszélesség `0.5` = 50% áthallás$Nszélesség `0 &nbsp;` = monó$N$Nboost `-0.8` &amp; szélesség `10` = ének eltávolítása :^)$N$Nha az EQ be van kapcsolva, a lemezek teljesen folytonosak lesznek (gapless), hagyd bekapcsolva nullán is, ha ez számít',
	"mt_drc": 'dinamikatartomány-tömörítés (hangerő-kiegyenlítő); az EQ-t is bekapcsolja, ha nem kell, az értékeit hagyd nullán (kivéve szélesség=1)$N$Nevvel sosem lesz túl hangos, -24 thresh és 12 ratio mellett -22 dB-nél megáll, biztonságos feltekerni a boost-ot 0.8-ra vagy akár 1.8-ra',
	"mt_ss": '`csönd átugrása; felgyorsít `ffwd`-szeresére a számok elején/végén, ha a hangerő `vol` alatt van és a pozíció a szám első/utolsó `start/end` százalékában van',
	"mt_ssvt": 'hangerő küszöb (0-255)">vol',
	"mt_ssts": 'aktív tartomány (%, eleje)">start',
	"mt_sste": 'aktív tartomány (%, vége)">end',
	"mt_sssm": 'lejátszási sebesség szorzó">ffwd',

	"mb_play": 'play',
	"mm_hashplay": 'lejátsszam ezt a fájlt?',
	"mm_m3u": '<code>Enter/OK</code>: Lejátszás\n<code>ESC/Cancel</code>: Szerkesztés',
	"mp_breq": "firefox 82+, chrome 73+, vagy iOS 15+ szükséges",
	"mm_bload": 'betöltés...',
	"mm_bconv": 'konvertálás ide: {0}, várj légy szíves...',
	"mm_opusen": 'a böngésződ nem támogatja az aac / m4a fájlokat;\nátkódolás opus-ba bekapcsolva',
	"mm_playerr": 'lejátszási hiba: ',
	"mm_eabrt": 'lejátszás megszakítva',
	"mm_enet": 'szakadozik a neted',
	"mm_edec": 'ez a fájl valahogy sérült??',
	"mm_esupp": 'a böngésződ nem ismeri ezt a formátumot',
	"mm_eunk": 'ismeretlen hiba',
	"mm_e404": 'audió hiba 404: fájl nem található.',
	"mm_e403": 'audió hiba 403: hozzáférés megtagadva.\n\npróbáld meg az F5-öt, hátha kiléptetett a rendszer',
	"mm_e415": 'audió hiba 415: átkódolás sikertelen; nézd meg a szerver logot.',
	"mm_e500": 'audió hiba 500: nézd meg a szerver logot.',
	"mm_e5xx": 'audió hiba; szerver hiba ',
	"mm_nof": 'nem találok több zenét a környéken',
	"mm_prescan": 'következő szám keresése...',
	"mm_scank": 'következő megvan:',
	"mm_uncache": 'gyorsítótár ürítve; minden számot újra letölt az újabb lejátszásnál',
	"mm_hnf": 'ez a szám már nem létezik',

	"im_hnf": 'ez a kép már nem létezik',

	"f_empty": 'a mappa üres',
	"f_chide": 'ez elrejti a(z) «{0}» oszlopot\n\nvisszakapcsolhatod a beállításoknál',
	"f_bigtxt": 'ez a fájl {0} MiB -- valóban megnyitod szövegként?',
	"f_bigtxt2": 'csak a fájl végét nézed meg? ez bekapcsolja a követést (tail) is, az új sorok élőben jelennek meg',
	"fbd_more": '<div id="blazy"><code>{0}</code> / <code>{1}</code> fájl látszik; <a href="#" id="bd_more">mutass még {2}-t</a> vagy <a href="#" id="bd_all">mutasd mindet</a></div>',
	"fbd_all": '<div id="blazy"><code>{0}</code> / <code>{1}</code> fájl látszik; <a href="#" id="bd_all">mutasd mindet</a></div>',
	"f_anota": 'csak {0} fájl van kijelölve a {1}-ből;\naz egész mappa kijelöléséhez görgess az aljára',

	"f_dls": 'a mappában lévő linkek letöltési linkekké alakultak',
	"f_dl_nd": 'mappa kihagyása (használd a zip/tar letöltést):\n',

	"f_partial": 'egy épp feltöltés alatt álló fájlt akarsz letölteni. Inkább válaszd azt, aminek megegyezik a neve, de nincs rajta a <code>.PARTIAL</code> kiterjesztés.\n\nha mégis OK-t nyomsz, valószínűleg hibás adatot kapsz.',

	"ft_paste": 'beillesztés: {0} elem$Ngyorsbillentyű: ctrl-V',
	"fr_eperm": 'nem tudom átnevezni:\nnincs “mozgatás” jogod ebben a mappában',
	"fd_eperm": 'nem tudom törölni:\nnincs “törlés” jogod ebben a mappában',
	"fc_eperm": 'nem tudom kivágni:\nnincs “ mozgatás ” jogod ebben a mappában',
	"fp_eperm": 'nem tudom beilleszteni:\nnincs “írás” jogod ebben a mappában',
	"fr_emore": 'jelölj ki legalább egy elemet az átnevezéshez',
	"fd_emore": 'jelölj ki legalább egy elemet a törléshez',
	"fc_emore": 'jelölj ki legalább egy elemet a kivágáshoz',
	"fcp_emore": 'jelölj ki legalább egy elemet a másoláshoz',

	"fs_sc": 'mappa megosztása',
	"fs_ss": 'kijelöltek megosztása',
	"fs_just1d": 'nem tudsz egyszerre több mappát,\nvagy fájlokat és mappákat vegyesen megosztani',
	"fs_abrt": '❌ mégse',
	"fs_rand": '🎲 random név',
	"fs_go": '✅ megosztás létrehozása',
	"fs_name": 'név',
	"fs_src": 'forrás',
	"fs_pwd": 'jelszó',
	"fs_exp": 'lejárat',
	"fs_tmin": 'perc',
	"fs_thrs": 'óra',
	"fs_tdays": 'nap',
	"fs_never": 'örök',
	"fs_pname": 'nem kötelező link név; üresen véletlenszerű lesz',
	"fs_tsrc": 'a megosztandó fájl vagy mappa',
	"fs_ppwd": 'nem kötelező jelszó',
	"fs_w8": 'megosztás létrehozása...',
	"fs_ok": '<code>Enter/OK</code>: Másolás vágólapra\n<code>ESC/Cancel</code>: Bezárás',

	"frt_dec": 'helyreállíthatja a hibás fájlneveket">url-decode',
	"frt_rst": 'eredeti nevek visszaállítása">↺ alaphelyzet',
	"frt_abrt": 'ablak bezárása">❌ mégse',
	"frb_apply": 'ÁTNEVEZÉS',
	"fr_adv": 'tömeges / metaadat / minta alapú átnevezés">haladó',
	"fr_case": 'kis/nagybetű érzékeny regex">case',
	"fr_win": 'windows-biztos nevek; cseréli a <code>&lt;&gt;:&quot;\\|?*</code> karaktereket japán teljes szélességűekre">win',
	"fr_slash": '<code>/</code> cseréje olyanra, ami nem hoz létre új mappát">no /',
	"fr_re": '`regex keresési minta; a csoportokra így hivatkozhatsz lent: `(1)`, `(2)` stb.',
	"fr_fmt": '`foobar2000 stílus:$N`(title)` = zeneszám címe,$N`[(artist) - ](title)` = kihagyja az előadót, ha üres$N`$lpad((tn),2,0)` = sorszám 2 számjegyen',
	"fr_pdel": 'törlés',
	"fr_pnew": 'mentés mint',
	"fr_pname": 'adj nevet az új presetnek',
	"fr_aborted": 'megszakítva',
	"fr_lold": 'régi név',
	"fr_lnew": 'új név',
	"fr_tags": 'tagek a kijelölt fájlokban (csak olvasásra):',
	"fr_busy": '{0} elem átnevezése...\n\n{1}',
	"fr_efail": 'átnevezés sikertelen:\n',
	"fr_nchg": '{0} név módosult a <code>win</code> vagy <code>no /</code> miatt\n\nfolytassuk az új nevekkel?',

	"fd_ok": 'törölve',
	"fd_err": 'törlés sikertelen:\n',
	"fd_none": 'semmi sem lett törölve; lehet, hogy a szerver tiltja (xbd)?',
	"fd_busy": '{0} elem törlése...\n\n{1}',
	"fd_warn1": 'TÖRLÖD ezt a(z) {0} elemet?',
	"fd_warn2": '<b>Utolsó esély!</b> Nem vonható vissza. Törlöd?',

	"fc_ok": '{0} elem kivágva',
	"fc_warn": '{0} elem kivágva\n\nde: csak <b>ez</b> a fül tudja beilleszteni őket\n(mivel a kijelölés brutálisan nagy)',

	"fcc_ok": '{0} elem vágólapra másolva',
	"fcc_warn": '{0} elem vágólapra másolva\n\nde: csak <b>ez</b> a fül tudja beilleszteni őket\n(mivel a kijelölés brutálisan nagy)',

	"fp_apply": 'nevek mentése',
	"fp_skip": 'ütközések kihagyása',
	"fp_ecut": 'előbb vágj ki vagy másolj valamit\n\nmegjegyzés: néha fülek között is megy',
	"fp_ename": '{0} elem nem mozgatható ide névütközés miatt. Adj nekik új nevet, vagy hagyd üresen (“kihagyás”) a skippeléshez:',
	"fcp_ename": '{0} elem nem másolható ide névütközés miatt. Adj nekik új nevet, vagy hagyd üresen (“kihagyás”) a skippeléshez:',
	"fp_emore": 'maradt még néhány névütközés',
	"fp_ok": 'mozgatás kész',
	"fcp_ok": 'másolás kész',
	"fp_busy": '{0} elem mozgatása...\n\n{1}',
	"fcp_busy": '{0} elem másolása...\n\n{1}',
	"fp_abrt": 'megszakítás...',
	"fp_err": 'mozgatás sikertelen:\n',
	"fcp_err": 'másolás sikertelen:\n',
	"fp_confirm": 'mozgassuk ide ezt a {0} elemet?',
	"fcp_confirm": 'másoljuk ide ezt a {0} elemet?',
	"fp_etab": 'nem sikerült a vágólap olvasása másik fülről',
	"fp_name": 'fájl feltöltése. Adj neki nevet:',
	"fp_both_m": '<h6>mi legyen?</h6><code>Enter</code> = Mozgatás: {0} elem innen: «{1}»\n<code>ESC</code> = Feltöltés: {2} fájl a gépedről',
	"fcp_both_m": '<h6>mi legyen?</h6><code>Enter</code> = Másolás: {0} elem innen: «{1}»\n<code>ESC</code> = Feltöltés: {2} fájl a gépedről',
	"fp_both_b": '<a href="#" id="modal-ok">Mozgatás</a><a href="#" id="modal-ng">Feltöltés</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Másolás</a><a href="#" id="modal-ng">Feltöltés</a>',

	"mk_noname": 'írj be egy nevet a bal oldali mezőbe :p',
	"nmd_i1": 'add meg a kiterjesztést is, pl. <code>.md</code>',
	"nmd_i2": 'csak <code>.{0}</code> fájlt hozhatsz létre, mert nincs törlési jogod',

	"tv_load": 'Szövegfájl betöltése:\n\n{0}\n\n{1}% ({2} / {3} MiB betöltve)',
	"tv_xe1": 'nem sikerült betölteni:\n\nhiba ',
	"tv_xe2": '404, fájl nem található',
	"tv_lst": 'szövegfájlok a mappában:',
	"tvt_close": 'vissza a mappába$Ngyorsbillentyű: M (vagy Esc)">❌ bezárás',
	"tvt_dl": 'fájl letöltése$Ngyorsbillentyű: Y">💾 letöltés',
	"tvt_prev": 'előző dokumentum$Ngyorsbillentyű: i">⬆ előző',
	"tvt_next": 'következő dokumentum$Ngyorsbillentyű: K">⬇ következő',
	"tvt_sel": 'kijelölés (vágáshoz/másoláshoz/törléshez)$Ngyorsbillentyű: S">kijelöl',
	"tvt_j": 'json formázás$Ngyorsbillentyű: shift-J">j',
	"tvt_edit": 'szerkesztés szövegként$Ngyorsbillentyű: E">✏️ szerkeszt',
	"tvt_tail": 'fájl figyelése; új sorok mutatása élőben">📡 követve',
	"tvt_wrap": 'sortörés">↵',
	"tvt_atail": 'gördítés az aljára rögzítve">⚓',
	"tvt_ctail": 'terminál színek (ansi escape) dekódolása">🌈',
	"tvt_ntail": 'visszapörgetési limit (hány bájt szöveg maradjon a memóriában)',

	"m3u_add1": 'szám hozzáadva az m3u listához',
	"m3u_addn": '{0} szám hozzáadva az m3u listához',
	"m3u_clip": 'm3u lista vágólapra másolva\n\nhozz létre egy új szövegfájlt valami.m3u névvel és illeszd bele; így már lejátszható lesz',

	"gt_vau": 'videó elrejtése, csak a hang lejátszása">🎧',
	"gt_msel": 'kijelölés engedélyezése; ctrl-klikk a felülbíráláshoz$N$N&lt;em&gt;ha aktív: dupla klikk a megnyitáshoz&lt;/em&gt;$N$Ngyorsbillentyű: S">tömeges',
	"gt_crop": 'középre vágott indexképek">crop',
	"gt_3x": 'nagy felbontású indexképek">3x',
	"gt_zoom": 'zoom',
	"gt_chop": 'vágás',
	"gt_sort": 'rendezés:',
	"gt_name": 'név',
	"gt_sz": 'méret',
	"gt_ts": 'dátum',
	"gt_ext": 'típus',
	"gt_c1": 'rövidebb fájlnevek',
	"gt_c2": 'hosszabb fájlnevek',

	"sm_w8": 'keresés...',
	"sm_prev": 'az alábbi eredmények egy korábbi keresésből vannak:\n  ',
	"sl_close": 'eredmények bezárása',
	"sl_hits": '{0} találat',
	"sl_moar": 'továbbiak betöltése',

	"s_sz": 'méret',
	"s_dt": 'dátum',
	"s_rd": 'útvonal',
	"s_fn": 'név',
	"s_ta": 'tagek',
	"s_ua": 'feltöltve',
	"s_ad": 'haladó',
	"s_s1": 'minimum MiB',
	"s_s2": 'maximum MiB',
	"s_d1": 'min. iso8601',
	"s_d2": 'max. iso8601',
	"s_u1": 'ezután töltve',
	"s_u2": 'vagy ez előtt',
	"s_r1": 'útvonal tartalmazza (szóközzel elválasztva)',
	"s_f1": 'név tartalmazza (negálás pl -nemez)',
	"s_t1": 'tagek tartalmazzák (^=kezdet, vég=$)',
	"s_a1": 'specifikus metaadatok',

	"md_eshow": 'nem sikerült megjeleníteni ',
	"md_off": '[📜<em>readme</em>] kikapcsolva a beállításokban -- rejtve',

	"badreply": 'Hibás válasz a szervertől',

	"xhr403": '403: Hozzáférés megtagadva\n\npróbáld az F5-öt, hátha kiléptetett a rendszer',
	"xhr0": 'ismeretlen hiba (valószínűleg megszakadt a kapcsolat)',
	"cf_ok": 'bocsi, DD' + wah + 'oS védelem bekapcsolt\n\nkb. 30 mp múlva folytatódik\n\nha nem történik semmi, nyomj F5-öt',
	"tl_xe1": 'almappák listázása sikertelen:\n\nhiba ',
	"tl_xe2": '404: mappa nem található',
	"fl_xe1": 'fájlok listázása sikertelen:\n\nhiba ',
	"fl_xe2": '404: mappa nem található',
	"fd_xe1": 'almappa létrehozása sikertelen:\n\nhiba ',
	"fd_xe2": '404: szülőmappa nincs meg',
	"fsm_xe1": 'üzenetküldés sikertelen:\n\nhiba ',
	"fsm_xe2": '404: szülőmappa nincs meg',
	"fu_xe1": 'unpost lista betöltése sikertelen:\n\nhiba ',
	"fu_xe2": '404: fájl nincs meg??',

	"fz_tar": 'tömörítetlen gnu-tar (linux / mac)',
	"fz_pax": 'tömörítetlen pax-formátumú tar (lassabb)',
	"fz_targz": 'gnu-tar gzip 3-as szinten$N$Náltalában lassú, inkább használd a sima tar-t',
	"fz_tarxz": 'gnu-tar xz 1-es szinten$N$Náltalában lassú, inkább használd a sima tar-t',
	"fz_zip8": 'zip utf8 nevekkel (régi windows alatt hibás lehet)',
	"fz_zipd": 'zip cp437 nevekkel (nagyon régi szoftverekhez)',
	"fz_zipc": 'cp437 crc32 gyorsítással,$NMS-DOS PKZIP v2.04g-hez (1993 októbere)$N(letöltés előtt hosszabb ideig tarthat a feldolgozás)',

	"un_m1": 'itt törölheted a nemrég feltöltött fájljaidat (vagy leállíthatod a futókat)',
	"un_upd": 'frissítés',
	"un_m4": 'vagy oszd meg az alábbi fájlokat:',
	"un_ulist": 'mutasd',
	"un_ucopy": 'másold',
	"un_flt": 'szűrő:&nbsp; az URL tartalmazza:',
	"un_fclr": 'szűrő törlése',
	"un_derr": 'törlés sikertelen:\n',
	"un_f5": 'valami elromlott, próbáld meg frissíteni az oldalt',
	"un_uf5": 'frissítened kell az oldalt (F5 vagy CTRL-R), mielőtt ezt leállíthatnád',
	"un_nou": '<b>figyelem:</b> a szerver túlterhelt a futó feltöltések listázásához; próbáld később',
	"un_noc": '<b>figyelem:</b> a kész feltöltések törlése nincs engedélyezve a szerveren',
	"un_max": 'az első 2000 fájl látszik (használd a szűrőt)',
	"un_avail": '{0} kész feltöltés törölhető<br />{1} folyamatban lévő leállítható',
	"un_m2": 'idő szerint rendezve (legfrissebb legelöl):',
	"un_no1": 'semmi! nincsenek nemrég feltöltött fájljaid',
	"un_no2": 'semmi! nincs a szűrőnek megfelelő friss feltöltés',
	"un_next": 'következő {0} fájl törlése',
	"un_abrt": 'leállítás',
	"un_del": 'törlés',
	"un_m3": 'legutóbbi feltöltések betöltése...',
	"un_busy": '{0} fájl törlése...',
	"un_clip": '{0} link vágólapra másolva',

	"u_https1": 'érdemesebb lenne',
	"u_https2": 'https-re váltani',
	"u_https3": 'a jobb sebességért',
	"u_ancient": 'lenyűgözően őskori a böngésződ -- talán <a href="#" onclick="goto(\'bup\')">használd inkább az egyszerű uploader-t</a>',
	"u_nowork": 'legalább Firefox 53, Chrome 57 vagy iOS 11 kell',
	"tail_2old": 'legalább Firefox 105, Chrome 71 vagy iOS 14.5 kell',
	"u_nodrop": 'a böngésződ túl öreg a drag-and-drop-hoz',
	"u_notdir": 'ez nem egy mappa!\n\na böngésződ túl öreg,\npróbáld meg inkább behúzni',
	"u_uri": 'képek behúzásához más ablakból,\ndobd rá a nagy feltöltés gombra',
	"u_enpot": 'váltás <a href="#">egyszerű UI-ra</a> (gyorsíthat a feltöltésen)',
	"u_depot": 'váltás <a href="#">vibráló UI-ra</a> (visszafoghatja a sebességet)',
	"u_gotpot": 'átváltottunk egyszerű UI-ra a sebesség miatt,\nde bármikor visszaválthatsz!',
	"u_pott": '<p>fájlok: &nbsp; <b>{0}</b> kész, &nbsp; <b>{1}</b> hiba, &nbsp; <b>{2}</b> fut, &nbsp; <b>{3}</b> vár</p>',
	"u_ever": 'ez az egyszerű feltöltő; az up2k-hoz legalább<br>chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1 kell',
	"u_su2k": 'ez az egyszerű feltöltő; az <a href="#" id="u2yea">up2k</a> sokkal jobb',
	"u_uput": 'sebességre optimalizál (ellenőrzés nélkül)',
	"u_ewrite": 'nincs írási jogod ebben a mappában',
	"u_eread": 'nincs olvasási jogod ebben a mappában',
	"u_enoi": 'fájlkeresés letiltva a szerveren',
	"u_enoow": 'felülírás nem fog menni; törlési jog kell hozzá',
	"u_badf": 'Ez a(z) {0} fájl ({1}-ből) kimaradt, valószínűleg jogok miatt:\n\n',
	"u_blankf": 'Ez a(z) {0} fájl ({1}-ből) teljesen üres; biztos feltöltöd?\n\n',
	"u_applef": 'Ez a(z) {0} fájl ({1}-ből) valószínűleg felesleges;\nNyomj <code>OK/Enter</code>-t a KIHAGYÁSHOZ,\nvagy <code>Cancel/ESC</code>-et a FELTÖLTÉSHEZ:\n\n',
	"u_just1": '\nlehet, hogy jobban működik, ha csak egy fájlt jelölsz ki',
	"u_ff_many": 'ha <b>Linux / MacOS / Android</b> rendszert használsz, ennyi fájl <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">fagyást okozhat Firefoxban!</a>\nha ez történik, próbáld újra (vagy használd a Chrome-ot).',
	"u_up_life": 'ez a feltöltés a befejezés után\n{0} múlva törlődik a szerverről',
	"u_asku": 'feltöltsem ezt a {0} fájlt ide: <code>{1}</code>?',
	"u_unpt": 'visszavonhatod/törölheted a feltöltést a bal felső 🧯 gombbal',
	"u_bigtab": '{0} fájl listázása következik\n\nez lefagyaszthatja a böngészőt, biztos?',
	"u_scan": 'Fájlok beolvasása...',
	"u_dirstuck": 'a rendszer elakadt az alábbi {0} elemnél; kihagyjuk őket:',
	"u_etadone": 'Kész ({0}, {1} fájl)',
	"u_etaprep": '(előkészítés...)',
	"u_hashdone": 'hashelés kész',
	"u_hashing": 'hash',
	"u_hs": 'kapcsolódás...',
	"u_started": 'a feltöltés elindult; lásd [🚀]',
	"u_dupdefer": 'másolat; a végén fogjuk feldolgozni',
	"u_actx": 'kattints ide, hogy a böngésző ne fogja vissza a sebességet,\nha más ablakba/fülre mész',
	"u_fixed": 'Oké! Javítva 👍',
	"u_cuerr": 'hiba a(z) {0} / {1}. egység feltöltésekor;\nvalószínűleg nem gond, folytatjuk\n\nfájl: {2}',
	"u_cuerr2": 'szerver elutasította az egységet ({0} / {1});\nkésőbb újrapróbáljuk\n\nfájl: {2}\n\nhiba ',
	"u_ehstmp": 'újrapróbálás; lásd jobb lent',
	"u_ehsfin": 'szerver elutasította a befejezést; újrapróbáljuk...',
	"u_ehssrch": 'szerver elutasította a keresést; újrapróbáljuk...',
	"u_ehsinit": 'szerver elutasította a kezdést; újrapróbáljuk...',
	"u_eneths": 'hálózati hiba a kapcsolódáskor; újrapróbálás...',
	"u_enethd": 'hálózati hiba az ellenőrzéskor; újrapróbálás...',
	"u_cbusy": 'várakozás, hogy a szerver megint bízzon bennünk hiba után...',
	"u_ehsdf": 'a szerveren elfogyott a hely!\n\naddig próbálkozunk, amíg valaki\nfel nem szabadít egy kis területet',
	"u_emtleak1": 'úgy tűnik, a böngésződ memóriát szivárogtat;\nkérlek',
	"u_emtleak2": ' <a href="{0}">válts https-re (ajánlott)</a> vagy ',
	"u_emtleak3": ' ',
	"u_emtleakc": 'próbáld a következőt:\n<ul><li>nyomj <code>F5</code>-öt</li><li>kapcsold ki az &nbsp;<code>mt</code>&nbsp; gombot a &nbsp;<code>⚙️ beállításokban</code></li><li>majd próbáld újra</li></ul>Lassabb lesz, de legalább lemegy.\nBocsi a kellemetlenségért!\n\nPS: a chrome v107 már <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">javított ezen</a>',
	"u_emtleakf": 'próbáld a következőt:\n<ul><li>nyomj <code>F5</code>-öt</li><li>kapcsold be az <code>egyszerű</code> módot<li>majd próbáld újra megint</li></ul>\nPS: remélhetőleg a firefox is <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">javítja egyszer</a>',
	"u_s404": 'nincs a szerveren',
	"u_expl": 'magyarázat',
	"u_maxconn": 'a legtöbb böngésző limitje 6, de Firefoxban az <code>about:config</code> alatt a <code>connections-per-server</code> értékkel növelhető',
	"u_tu": '<p class="warn">FIGYELEM: turbo bekapcsolva, <span>&nbsp;lehet, hogy nem veszi észre a félbeszakadt feltöltéseket; lásd a súgót</span></p>',
	"u_ts": '<p class="warn">FIGYELEM: turbo bekapcsolva, <span>&nbsp;a keresési eredmények hibásak lehetnek; lásd a súgót</span></p>',
	"u_turbo_c": 'turbo letiltva a szerveren',
	"u_turbo_g": 'turbo kikapcsolva, mert nincs jogod mappalistázáshoz ezen a köteten',
	"u_life_cfg": 'autotörlés <input id="lifem" p="60" /> perc (vagy <input id="lifeh" p="3600" /> óra) múlva',
	"u_life_est": 'a feltöltés törlődni fog ekkor: <span id="lifew" tt="helyi idő">---</span>',
	"u_life_max": 'ez a mappa kényszeríti a\nmax élettartamot: {0}',
	"u_unp_ok": 'unpost engedélyezve eddig: {0}',
	"u_unp_ng": 'unpost NEM lesz engedélyezve',
	"ue_ro": 'ebben a mappában csak olvasási jogod van\n\n',
	"ue_nl": 'nem vagy belépve',
	"ue_la": 'jelenleg mint “{0}” vagy bejelentkezve',
	"ue_sr": 'kereső módban vagy\n\nválts feltöltésre a nagy KERESÉS gomb melletti nagyítóra 🔎 kattintva,\nés próbáld újra\n\nbocsi',
	"ue_ta": 'próbáld meg újra, most már mennie kell',
	"ue_ab": 'ez a fájl már fel van töltve egy másik mappába, várd meg, amíg az kész lesz.\n\nmegszakíthatod a korábbi próbálkozást a bal felső 🧯 gombbal',
	"ur_1uo": 'OK: Fájl sikeresen feltöltve',
	"ur_auo": 'OK: Mind a(z) {0} fájl feltöltve',
	"ur_1so": 'OK: Fájl megvan a szerveren',
	"ur_aso": 'OK: Mind a(z) {0} fájl megvan a szerveren',
	"ur_1un": 'A feltöltés nem sikerült',
	"ur_aun": 'Az összes ({0}) feltöltés megszakadt',
	"ur_1sn": 'Fájl nincs a szerveren',
	"ur_asn": 'A(z) {0} fájl nincs a szerveren',
	"ur_um": 'Kész;\n{0} sikeres,\n{1} sajnos nem sikerült',
	"ur_sm": 'Kész;\n{0} megvan a szerveren,\n{1} nincs meg',

	"rc_opn": 'megnyitás',
	"rc_ply": 'lejátszás',
	"rc_pla": 'lejátszás audióként',
	"rc_txt": 'megnyitás szövegként',
	"rc_md": 'megnyitás markdownként',
	"rc_dl": 'letöltés',
	"rc_zip": 'letöltés archívumként',
	"rc_cpl": 'link másolása',
	"rc_del": 'törlés',
	"rc_cut": 'kivágás',
	"rc_cpy": 'másolás',
	"rc_pst": 'beillesztés',
	"rc_rnm": 'átnevezés',
	"rc_nfo": 'új mappa',
	"rc_nfi": 'új fájl',
	"rc_sal": 'összes kijelölése',
	"rc_sin": 'kijelölés megfordítása',
	"rc_shf": 'mappa megosztása',
	"rc_shs": 'kijelöltek megosztása',

	"lang_set": 'frissítsünk, hogy átálljon a nyelv?',

	"splash": {
		"a1": 'frissítés',
		"b1": 'üdv idegen &nbsp; <small>(nem vagy bejelentkezve)</small>',
		"c1": 'kilépés',
		"d1": 'dump stack',
		"d2": 'minden aktív szál állapotának mutatása',
		"e1": 'config újratöltés',
		"e2": 'konfigurációs fájlok (fiókok/kötetek) és e2ds kötetek újraszkennelése$N$Nmegjegyzés: a globális beállításokhoz$Nteljes újraindítás kell',
		"f1": 'böngészhető:',
		"g1": 'ide tudsz feltölteni:',
		"cc1": 'egyéb dolgok:',
		"h1": 'k304 kikapcsolása',
		"i1": 'k304 bekapcsolása',
		"j1": 'a k304 lekapcsolja a klienst minden HTTP 304-nél, ami segíthet némely akadózó proxynál, de amúgy lassítja a dolgokat',
		"k1": 'beállítások alaphelyzetbe állítása',
		"l1": 'jelentkezz be a többiért:',
		"ls3": 'belépés',
		"lu4": 'felhasználónév',
		"lp4": 'jelszó',
		"lo3": '“{0}” kijelentkeztetése mindenhonnan',
		"lo2": 'minden böngészőben lelövi a munkamenetet',
		"m1": 'üdv újra,',
		"n1": '404 nincs meg &nbsp;┐( ´ -`)┌',
		"o1": 'vagy nincs jogod -- próbálj belépni vagy <a href="' + SR + '/?h">menj a főoldalra</a>',
		"p1": '403 tiltva &nbsp;~┻━┻',
		"q1": 'kell egy jelszó vagy <a href="' + SR + '/?h">menj a főoldalra</a>',
		"r1": 'vissza a főoldalra',
		".s1": 'újraszkennelés',
		"t1": 'művelet',
		"u2": 'utolsó írás óta eltelt idő$N( feltöltés / átnevezés / ... )$N$N17n = 17 nap$N1ó23 = 1 óra 23 perc$N4p56 = 4 perc 56 másodperc',
		"v1": 'csatlakozás',
		"v2": 'szerver használata helyi meghajtóként',
		"w1": 'váltás https-re',
		"x1": 'jelszó megváltoztatása',
		"y1": 'megosztások szerkesztése',
		"z1": 'megosztás feloldása:',
		"ta1": 'írd be az új jelszavad',
		"ta2": 'új jelszó még egyszer:',
		"ta3": 'elírtad; próbáld újra',
		"nop": 'HIBA: A jelszó nem lehet üres',
		"nou": 'HIBA: A felhasználónév és jelszó nem lehet üres',
		"aa1": 'érkező fájlok:',
		"ab1": 'no304 kikapcsolása',
		"ac1": 'no304 bekapcsolása',
		"ad1": 'a no304 kikapcsolja a gyorsítótárazást; akkor használd, ha a k304 nem segített. Figyelem: ez jelentős adatforgalmat generál!',
		"ae1": 'futó letöltések:',
		"af1": 'utóbbi feltöltések mutatása',
		"ag1": 'idp cache megtekintése',
	},
};
